/*
  Author:  Jonathan Bondzie, Dr. Chuck Yeung
           Lennard Gas Simulation Source

	   Copyright (C) 1999  Penn State University

	   This program is free software; you can redistribute it and/or
	   modify it under the terms of the GNU General Public License
	   as published by the Free Software Foundation;
	   
	   This program is distributed in the hope that it will be useful,
	   but WITHOUT ANY WARRANTY; without even the implied warranty of
	   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	   GNU General Public License for more details.
	   
	   You should have received a copy of the GNU General Public License
	   along with this program; if not, write to the Free Software
	   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
	   02111-1307, USA.

	   email jab341@psu.edu
*/

/*include file with definitions of functions in setupGraphics.c*/

class Variables
{
public:
  float g;
  float blennard;
  float kinetic_energy;
  float potential_energy;
  float total_energy;
  float t;                 /* current time */
  float lx;                /* x box size */
  float ly;	           /* y box size */
  float dt;        	   /* time step */
  float end_time;  	   /* ending time */
  float update_interval;   /* used as interval between graphics calls */
  float temp;              /* system temperature */
  float binsize; 
  float fv_lx;             /* holds the sum of the x velocities*/
  float fv_ly;             /* holds the sum of the y velocities*/
  float ftime_interval;    /* interval for calculating the pressure*/
  float total_pressure;    /* total pressure on the walls */
  float instant_pressure;  
  float itime_checker;	   /* intial time when ever pressure is calculated*/
  float *fx;               /* x forces  */
  float *fy;               /* y forces  */
  float *fx0;              /* holder for previous x forces */
  float *fy0;              /* holder for previous y forces */	
  int nparticles;
  int *neighbours;         /* contains the neighbour list */
  int mask;                /* two bit binary number that determines the state of update */
  int reset;
  int set_state;           /* sets the state of the radio button */ 
  int display_integral;    /* displays the integrated physical quantities */
  double   *x,  *y;        /* x and y positions */
  double   *vx, *vy;       /* vx and vy velociti*/    
  double   *prev_x;        /* this contains the previous x positions*/
  double   *prev_y;        /* this contains the previous y positions*/
  unsigned int* histogram; /* contains the bin info, for max Bolz distrib*/
  unsigned long seed1;     /* seeds for random number generator */
  unsigned long seed2;
  unsigned long seed3;
  unsigned int ndigit;     /* precision for gcvt a double to string conversion function */
  unsigned int dump;       /* dump parametric quantities */
  Variables();
};

class Widgets
{
public:
  GC	 dgr_gc;		 /* graphics context structure */
  Widget dgr_time_text;	         /* text widget for holding current time */ 
  Widget dgr_endtime_text;       /* widget holds endtime in cmd window */
  Widget dgr_message_window;     /* displays messages at the top of the drawing canvas */
  Widget dgr_energy_window;      /* energy window    */
  Widget dgr_kinetic_window;     /* kinetic energy window */
  Widget dgr_potential_window;   /* potential energy window */
  Widget dgr_total_energy_window;/* total energy ( sum of potential and kinetic energies )*/
  Widget dgr_itemp;              /* instantanuos temperature widget */
  Widget dgr_ipressure;          /* instantanuos presure */
  Widget dgr_mainwindow;	 /* the mainwindow */
  Widget dgr_drawing_area;       /* the main drawing area widget */
  Widget dgr_form;               /* form widget */
  Widget dgr_widget;             /* just a container widget */
};


/* functions within SetupInitialGraphics */
extern XtAppContext SetupInitialGraphics(int argc,char** argv,Variables* ptr);
extern Widgets* ReturnClassAddress(void);

/* functions within lennard.cpp */
extern void Neighbour_List(Variables* ptr);
extern float update_position(Variables* ptr);
extern void InitializeArrays(Variables* ptr);      /* initializes all the dynamic arrays */
extern void NoGraphicsRoutine(Variables* ptr);
extern void make_initial_state(Variables* ptr);
extern void kinetic_energy_calc(Variables* ptr);
extern void potential_energy_calc(Variables* ptr);
extern void function_Xple_check(int pp,Variables* ptr);
extern void MaxBoltzMemAlloc(float avg_velocity,Variables* ptr);

/* functions within FormCreationFunction.cpp*/
extern void CallFormChildren(void);                      /* creates the children for the form widget*/
extern void Function(Variables* ptr);
extern char* GetTextString(Widget widget);               /* gets the text store in a text widget */ 
extern void SetTextString(Widget widget,double string);  /* string function for text widgets */
extern void MessageDialogCreationFunction(Widget parent,char* string);
extern void FormPushButtonCallback(Widget widget,XtPointer client_data,XtPointer call_data);           

/* functions within DrawCircles.cpp*/
extern void DrawCircles(Variables* ptr);
extern void refreshDisplayAndScales(Variables* ptr);

/* functions within FunctionRescale.cpp*/
extern void RescaleGraphics(Dimension initialwidth,Dimension width,float* pixel_scale,
			    int* diameter,float lx);



